# -*- coding: utf-8 -*-
# Generated by Django 1.11.4 on 2017-08-17 13:47
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Comuna',
            fields=[
                ('codigo', models.CharField(max_length=10, primary_key=True, serialize=False)),
                ('tipo', models.CharField(max_length=10)),
                ('nombre', models.CharField(max_length=255)),
                ('lat', models.CharField(max_length=50)),
                ('lng', models.CharField(max_length=50)),
                ('url', models.URLField()),
            ],
        ),
        migrations.CreateModel(
            name='Provincia',
            fields=[
                ('codigo', models.CharField(max_length=10, primary_key=True, serialize=False)),
                ('tipo', models.CharField(max_length=10)),
                ('nombre', models.CharField(max_length=255)),
                ('lat', models.CharField(max_length=50)),
                ('lng', models.CharField(max_length=50)),
                ('url', models.URLField()),
            ],
        ),
        migrations.CreateModel(
            name='Region',
            fields=[
                ('codigo', models.CharField(max_length=10, primary_key=True, serialize=False)),
                ('tipo', models.CharField(max_length=10)),
                ('nombre', models.CharField(max_length=255)),
                ('lat', models.CharField(max_length=50)),
                ('lng', models.CharField(max_length=50)),
                ('url', models.URLField()),
            ],
        ),
        migrations.AddField(
            model_name='provincia',
            name='region',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='dpa_chile.Region'),
        ),
        migrations.AddField(
            model_name='comuna',
            name='provincia',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='dpa_chile.Provincia'),
        ),
        migrations.AddField(
            model_name='comuna',
            name='region',
            field=models.ForeignKey(default=None, on_delete=django.db.models.deletion.CASCADE, to='dpa_chile.Region'),
            preserve_default=False,
        ),
    ]



# -*- coding: utf-8 -*-
from __future__ import unicode_literals
from django.db import models
from django.utils.encoding import python_2_unicode_compatible


@python_2_unicode_compatible
class Region(models.Model):
    """
    Region object
    """
    codigo = models.CharField(max_length=10, primary_key=True)
    tipo = models.CharField(max_length=10)
    nombre = models.CharField(max_length=255)
    lat = models.CharField(max_length=50)
    lng = models.CharField(max_length=50)
    url = models.URLField(max_length=200)

    def __str__(self):
        return self.nombre


@python_2_unicode_compatible
class Provincia(models.Model):
    """
    Provincia object
    """
    codigo = models.CharField(max_length=10, primary_key=True)
    tipo = models.CharField(max_length=10)
    nombre = models.CharField(max_length=255)
    lat = models.CharField(max_length=50)
    lng = models.CharField(max_length=50)
    url = models.URLField(max_length=200)
    region = models.ForeignKey('Region')

    def __str__(self):
        return self.nombre


@python_2_unicode_compatible
class Comuna(models.Model):
    """
    Comuna object
    """
    codigo = models.CharField(max_length=10, primary_key=True)
    tipo = models.CharField(max_length=10)
    nombre = models.CharField(max_length=255)
    lat = models.CharField(max_length=50)
    lng = models.CharField(max_length=50)
    url = models.URLField(max_length=200)
    region = models.ForeignKey('Region')
    provincia = models.ForeignKey('Provincia')

    def __str__(self):
        return self.nombre



# -*- coding: utf-8 -*-
from __future__ import unicode_literals
import urllib3
import json
from bunch import bunchify
from django.core.management.base import BaseCommand, CommandError
from dpa_chile.models import Region, Provincia, Comuna

safe_ascci = {'\xc1': 'Á', '\xc9': 'É', '\xcd': 'Í', '\xd3': 'Ó', '\xda': 'Ú',
              '\xdc': 'U', '\xd1': 'Ñ', '\xc7': 'C', '\xed': 'i', '\xf3': 'o',
              '\xf1': 'ñ', '\xe7': 'c', '\xba': '', '\xb0': '', '\xe1': 'á',
              '\xe2': 'a', '\xe3': 'a', '\xe4': 'a', '\xe5': 'a', '\xe8': 'e',
              '\xe9': 'é', '\xea': 'e', '\xeb': 'e', '\xec': 'i', '\xed': 'í',
              '\xee': 'i', '\xef': 'i', '\xf2': 'o', '\xf3': 'ó', '\xf4': 'o',
              '\xf5': 'o', '\xf0': 'o', '\xf9': 'u', '\xfa': 'u', '\xfb': 'u',
              '\xfc': 'u', '\xe5': 'a'}


class Command(BaseCommand):
    help = 'Populate Political-Administrative Division of Chile'

    def handle(self, *args, **options):
        urllib3.disable_warnings()
        http = urllib3.PoolManager()

        r = http.request('GET', 'https://apis.modernizacion.cl/dpa/regiones')
        j = json.loads(r.data)
        regiones = bunchify(j)

        for region in regiones:
            self.stdout.write(self.style.SUCCESS('Region: {}'.format(region.nombre)))
            try:
                fields = {'tipo': region.tipo,
                          'nombre': region.nombre,
                          'lat': str(region.lat),
                          'lng': str(region.lng),
                          'url': region.url}

                obj, created = Region.objects.update_or_create(
                    codigo=region.codigo, defaults=fields)

                self.provincia(obj, http)
            except Exception as e:
                raise CommandError('Fail populate - Exception: {}'.format(e))

        self.stdout.write(
            self.style.SUCCESS('Successfully populate dpa chile'))

    def provincia(self, region, http):
        p = http.request(
            'GET',
            'https://apis.modernizacion.cl/dpa/regiones/{}/provincias'.format(region.codigo))
        j = json.loads(p.data)
        provincias = bunchify(j)
        for provincia in provincias:
            self.stdout.write(self.style.SUCCESS('Provincia: {}'.format(provincia.nombre)))
            try:
                fields = {'tipo': provincia.tipo,
                          'nombre': provincia.nombre,
                          'lat': str(provincia.lat),
                          'lng': str(provincia.lng),
                          'url': provincia.url,
                          'region': region}

                obj, created = Provincia.objects.update_or_create(
                    codigo=provincia.codigo, defaults=fields)

                self.comunas(obj, http)
            except Exception as e:
                raise CommandError('Fail populate - Exception: {}'.format(e))

    def comunas(self, provincia, http):
        c = http.request(
            'GET',
            'https://apis.modernizacion.cl/dpa/regiones/{}/provincias/{}/comunas'.format(provincia.region.codigo,
                                                                                         provincia.codigo))
        j = json.loads(c.data)
        comunas = bunchify(j)
        for comuna in comunas:
            self.stdout.write(self.style.SUCCESS('Comuna: {}'.format(comuna.nombre)))
            try:
                fields = {'tipo': comuna.tipo,
                          'nombre': comuna.nombre,
                          'lat': str(comuna.lat),
                          'lng': str(comuna.lng),
                          'url': comuna.url,
                          'region': provincia.region,
                          'provincia': provincia}

                obj, created = Comuna.objects.update_or_create(
                    codigo=comuna.codigo, defaults=fields)

            except Exception as e:
                raise CommandError('Fail populate - Exception: {}'.format(e))




from setuptools import setup
# To use a consistent encoding
from codecs import open
from os import path

here = path.abspath(path.dirname(__file__))

long_description = open('README.md').read()

setup(
    name='django-dpa-chile',

    # Versions should comply with PEP440.  For a discussion on single-sourcing
    # the version across setup.py and the project code, see
    # https://packaging.python.org/en/latest/single_source_version.html
    version='3.0.0',

    description='Political-Administrative Division of Chile',
    long_description=long_description,

    # The project's main homepage.
    url='https://github.com/jupitercl/django-dpa-chile',

    # Author details
    author='Francisco Jordan',
    author_email='franciscojordan@live.com',

    # Choose your license
    license='MIT',

    # See https://pypi.python.org/pypi?%3Aaction=list_classifiers
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Environment :: Web Environment',
        'Framework :: Django :: 1.11',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Natural Language :: Spanish',
        'Operating System :: Unix',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
    ],

    # What does your project relate to?
    keywords='django chile comunas regiones provincias',

    # You can just specify the packages manually here if your project is
    # simple. Or you can use find_packages().
    packages=[
        'dpa_chile',
        'dpa_chile.migrations',
        'dpa_chile.management',
        'dpa_chile.management.commands'],

    include_package_data=True,

    # List run-time dependencies here.  These will be installed by pip when
    # your project is installed. For an analysis of "install_requires" vs pip's
    # requirements files see:
    # https://packaging.python.org/en/latest/requirements.html
    install_requires=[
        'django>=1.7',
        'urllib3',
        'bunch'
    ],
)
